# Kaki - Advanced application library for Kivy

(work in progress)

This library enhance Kivy frameworks with opiniated features such as:

- Auto reloading kv or py (`watchdog` required, limited to some uses cases)
- Idle detection support

## WIP

- State management
- API (easy class to communicate with external api, download medias, etc)
- Better logger (based on `logbook`)
- Additionnal widgets (`ProgressSpinner`, `SwitchContainer`, `CoverImage`)
